package com.fzfd.web;

import java.util.Hashtable;
import java.util.Enumeration;
import java.util.ArrayList;

import java.io.Serializable;
import java.io.IOException;

import javax.servlet.http.HttpServletRequest;

/**
 * Basic transport between controller and facades.
 *
 * @author Efraim Berkovich
 * @version 1.4
 */

public class Message implements Serializable
{

  /**
   * Holds the message values.
   */
  protected Hashtable values;



  /**
   * Create a message
   */
  public Message( )
  {
    values = new Hashtable();
  }


  /**
   * Create message from Http Request
   */
  public Message( HttpServletRequest request )
  {
    values = new Hashtable();

    Enumeration enum = request.getParameterNames();
    while( enum.hasMoreElements() )
    {
      String nm = (String)enum.nextElement();
      String val = (String)request.getParameter( nm );
      setProperty( nm, val );
    }

  }


  /**
   * Get property value by name.
   */
  public Object getProperty( String propertyName )
  {
    return values.get( propertyName );
  }

  /**
   * Return property as boolean
   */
  public boolean getPropertyAsBoolean( String propertyName, boolean defaultValue )
  {
    String s = getPropertyAsString( propertyName );
    if( s == null ) return defaultValue;
    return Boolean.getBoolean( s );
  }


  /**
   * Return property as boolean, with false default.
   */
  public boolean getPropertyAsBoolean( String propertyName )
  {
    return getPropertyAsBoolean( propertyName, false );
  }


  /**
   * Return property as double
   */
  public double getPropertyAsDouble( String propertyName )
  {
    return Double.parseDouble( getPropertyAsString( propertyName ) );
  }


  /**
   * Return property as float
   */
  public float getPropertyAsFloat( String propertyName )
  {
    return Float.parseFloat( getPropertyAsString( propertyName ) );
  }


  /**
   * Return property as integer
   */
  public int getPropertyAsInteger( String propertyName )
  {
    return Integer.parseInt( getPropertyAsString( propertyName ) );
  }


  /**
   * Return property as long
   */
  public long getPropertyAsLong( String propertyName )
  {
    return Long.parseLong( getPropertyAsString( propertyName ) );
  }


  /**
   * Return property as string
   */
  public String getPropertyAsString( String propertyName )
  {
    Object o = values.get( propertyName );
    if( o != null )
    {
      return o.toString();
    }
    else
    {
      return null;
    }
  }



  /**
   * Return string or "" if null or not found
   */
  public String getPropertyAsStringOrBlank( String propertyName )
  {
    Object o = values.get( propertyName );
    if(o == null)
    {
      return "";
    }
    else
    {
      return o.toString();
    }
  }


  /**
   * Return string array of all property names in message
   */
  public String[] getPropertyNames()
  {
    Enumeration iter = values.keys();
    ArrayList names = new ArrayList( values.size() );

    while( iter.hasMoreElements() )
    {
      names.add( iter.nextElement() );
    }

    return (String[])names.toArray( new String[ names.size() ] );
  }


  /**
   * Return object array of all properties in message
   */
  public Object[] getPropertyValues()
  {
    Enumeration iter = values.elements();
    ArrayList vals = new ArrayList( values.size() );

    while( iter.hasMoreElements() )
    {
      vals.add( iter.nextElement() );
    }

    return (Object[])vals.toArray( new Object[ vals.size() ] );
  }


  /**
   * Is a property available?
   */
  public boolean isPropertyDefined( String propertyName )
  {
    return values.containsKey( propertyName );
  }

  /**
   * Remove property value from message.
   */
  public void removeProperty( String propertyName )
  {
    values.remove( propertyName );
  }


  /**
   * Set the value for a property
   * @param propertyName String name of the property
   * @param propertyValue Serializable All values must be seriablizable.
   */
  public void setProperty( String propertyName, Serializable propertyValue )
  {
    values.put( propertyName, propertyValue );
  }





  public String toString()
  {
    return values.toString();
  }

}