package com.fzfd.web;

import java.util.HashMap;
import java.util.Iterator;

/**
 * Holds mapping from business calls to JSP pages which display the response.
 * Also has method for invoking the business method requested.
 *
 * @author Efraim Berkovich
 * @version 1.4
 */

public class RoutingMap
{

  /** login page */
  private String loginPage                                = "";
  /** General error page   */
  private String   errorPage                              = "";
  /** Not authorized page   */
  private String   notAuthorizedPage                      = "";
  /** Logged out page   */
  private String   logoutPage                             = "";
  /** URL for controller   */
  private String   controllerURL                          = "";
  /** URL for login servlet   */
  private String   loginURL                               = "";
  /** session interval in secs  */
  private int      sessionTime                            = 30 * 60;


  private HashMap navigationMap = new HashMap();


  // HTTP Tag which contains the service to which the request should be routed
  public static String SERVICE_REQUESTED                = "service-request";
  // HTTP tag for the source
  public static String SERVICE_SOURCE                   = "service-source";


  public static String SERVICE_RESPONSE                 = "service-response";
  public static String USER_ROLES                       = "user-roles";

  // normally this mapping of services would be done in a data-driven way

  public static String SERVICE_LOGIN                    = "login";
  public static String SERVICE_EDIT                     = "Account.editRecord";
  public static String SERVICE_VIEW                     = "Account.viewRecords";
  public static String SERVICE_LOGS                     = "System.getLogs";
  public static String SERVICE_CHANGE_PASSWORD          = "Main.changePassword";
  public static String SERVICE_MAIN                     = "Main";


  /**
   * Initialize the mappings
   */
  public RoutingMap(  String loginPage
                  ,   String  errorPage
                  ,   String  notAuthorizedPage
                  ,   String  logoutPage
                  ,   String  controllerURL
                  ,   String  loginURL
                  ,   int     sessionTimeOut
                   )
  {
    this.loginPage = loginPage;
    this.errorPage = errorPage;
    this.notAuthorizedPage = notAuthorizedPage;
    this.logoutPage = logoutPage;
    this.controllerURL = controllerURL;
    this.loginURL = loginURL;
    this.sessionTime = sessionTimeOut;

    // note: this is meant for illustrative purposes. should be done
    //   as a data-driven configuration design

    navigationMap.put( SERVICE_LOGIN, "/main.jsp" );
    navigationMap.put( SERVICE_CHANGE_PASSWORD, "/main.jsp" );
    navigationMap.put( SERVICE_LOGS, "/main.jsp" );
    navigationMap.put( SERVICE_EDIT, "/main.jsp" );
    navigationMap.put( SERVICE_VIEW, "/main.jsp" );
    navigationMap.put( SERVICE_MAIN, "/main.jsp" );

  }


  /**
   * Get the JSP page for login
   */
  public String getLoginPage()
  {
    return loginPage;
  }



  /**
   * Get the JSP page to which to forward trapped Exceptions
   * @return page the path of the JSP
   */
  public String getErrorPage()
  {
    return errorPage;
  }


  /**
   * Get the JSP page for when the user is logged out
   * @return page the path of the JSP
   */
  public String getLogoutPage()
  {
    return logoutPage;
  }


  /**
   * Get the session interval
   * @return number of seconds to maintain session
   */
  public int getSessionTimeOut()
  {
    return sessionTime;
  }


  /**
   * Get the page which will be displayed when a non-logged in user
   * is trying to access services other than loginUser or when a valid
   * user is trying to access services other than those allowed for the user.
   * @return page the path of the JSP
   *
   */
  public String getNotAuthorizedPage( )
  {
    return notAuthorizedPage;
  }


  /**
   * Get the login servlet uri.
   * @return the login servlet uri.
   *
   */
  public String getLoginURL( )
  {
    return loginURL;
  }


  /**
   * Get the controller servlet uri.
   * @return the conroller servlet uri.
   *
   */
  public String getControllerURL( )
  {
    return controllerURL;
  }



  /**
   * Figure out where to route the response
   * based on the navigation map
   * @param service
   * @return JSP path
   */
  public String findForwardingURL( String service )
  {
    String forwardingURL = (String)navigationMap.get( service );
    if( forwardingURL == null )
    {
      String message = "Cannot find mapping for URI key: " + service;
      throw new NullPointerException( message );
    }

    return forwardingURL;
  }



}